@@ -13,10 +13,13 @@ from PyQt4 import QtCore, QtGui
 from ui.mainWindow import MainWindow
 
 if __name__ == "__main__":
-    import sys
-    app = QtGui.QApplication(sys.argv)
-    ui = MainWindow()
-    ui.showFullScreen() 
-    ui.setWindowTitle('AnselA-Image Darkroom')
-    ui.show()
-    sys.exit(app.exec_())
+    try:
+        import sys
+        app = QtGui.QApplication(sys.argv)
+        ui = MainWindow()
+        ui.showFullScreen() 
+        ui.setWindowTitle('AnselA-Image Darkroom')
+        ui.show()
+        sys.exit(app.exec_())
+    except Exception, e:
+        print e
\ No newline at end of file
